@@ -1,4 +1,4 @@
-// Copyright (C) 2016-2018 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2016-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -134,11 +134,25 @@ CtrlAgentProcess::configure(isc::data::ConstElementPtr config_set,
         }
 
         uint16_t server_port = ctx->getHttpPort();
+        bool use_https = false;
 
         // Only open a new listener if the configuration has changed.
         if (http_listeners_.empty() ||
             (http_listeners_.back()->getLocalAddress() != server_address) ||
             (http_listeners_.back()->getLocalPort() != server_port)) {
+            // Create a TLS context.
+            TlsContextPtr tls_context;
+            // When TLS is enabled configure it.
+            if (!ctx->getCertFile().empty()) {
+                TlsContext::configure(tls_context,
+                                      TlsRole::SERVER,
+                                      ctx->getTrustAnchor(),
+                                      ctx->getCertFile(),
+                                      ctx->getKeyFile(),
+                                      ctx->getCertRequired());
+                use_https = true;
+            }
+
             // Create response creator factory first. It will be used to
             // generate response creators. Each response creator will be
             // used to generate answer to specific request.
@@ -148,7 +162,7 @@ CtrlAgentProcess::configure(isc::data::ConstElementPtr config_set,
             // prepared to accept incoming connection.
             HttpListenerPtr http_listener
                 (new HttpListener(*getIoService(), server_address,
-                                  server_port, rcf,
+                                  server_port, tls_context, rcf,
                                   HttpListener::RequestTimeout(TIMEOUT_AGENT_RECEIVE_COMMAND),
                                   HttpListener::IdleTimeout(TIMEOUT_AGENT_IDLE_CONNECTION_TIMEOUT)));
 
@@ -163,9 +177,13 @@ CtrlAgentProcess::configure(isc::data::ConstElementPtr config_set,
         }
 
         // Ok, seems we're good to go.
-        LOG_INFO(agent_logger, CTRL_AGENT_HTTP_SERVICE_STARTED)
-            .arg(server_address.toText()).arg(server_port);
-
+        if (use_https) {
+          LOG_INFO(agent_logger, CTRL_AGENT_HTTPS_SERVICE_STARTED)
+              .arg(server_address.toText()).arg(server_port);
+        } else {
+            LOG_INFO(agent_logger, CTRL_AGENT_HTTP_SERVICE_STARTED)
+                .arg(server_address.toText()).arg(server_port);
+        }
     });
 
     int rcode = 0;
