@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -7,7 +7,6 @@
 #include <config.h>
 
 #include <communication_state.h>
-#include <exceptions/exceptions.h>
 #include <ha_log.h>
 #include <ha_service_states.h>
 #include <cc/data.h>
@@ -113,7 +112,12 @@ CommunicationState::setPartnerScopes(ConstElementPtr new_scopes) {
 void
 CommunicationState::startHeartbeat(const long interval,
                                    const std::function<void()>& heartbeat_impl) {
-    startHeartbeatInternal(interval, heartbeat_impl);
+    if (MultiThreadingMgr::instance().getMode()) {
+        std::lock_guard<std::mutex> lk(*mutex_);
+        startHeartbeatInternal(interval, heartbeat_impl);
+    } else {
+        startHeartbeatInternal(interval, heartbeat_impl);
+    }
 }
 
 void
@@ -159,6 +163,16 @@ CommunicationState::startHeartbeatInternal(const long interval,
 
 void
 CommunicationState::stopHeartbeat() {
+    if (MultiThreadingMgr::instance().getMode()) {
+        std::lock_guard<std::mutex> lk(*mutex_);
+        stopHeartbeatInternal();
+    } else {
+        stopHeartbeatInternal();
+    }
+}
+
+void
+CommunicationState::stopHeartbeatInternal() {
     if (timer_) {
         timer_->cancel();
         timer_.reset();
@@ -342,9 +356,9 @@ CommunicationState::getReport() const {
     report->set("unacked-clients", Element::create(static_cast<long long>(getUnackedClientsCount())));
 
     long long unacked_clients_left = 0;
-    if (isCommunicationInterrupted() && (config_->getMaxUnackedClients() > getUnackedClientsCount())) {
+    if (isCommunicationInterrupted() && (config_->getMaxUnackedClients() >= getUnackedClientsCount())) {
         unacked_clients_left = static_cast<long long>(config_->getMaxUnackedClients() -
-                                                      getUnackedClientsCount());
+                                                      getUnackedClientsCount() + 1);
     }
     report->set("unacked-clients-left", Element::create(unacked_clients_left));
     report->set("analyzed-packets", Element::create(static_cast<long long>(getAnalyzedMessagesCount())));
@@ -354,8 +368,7 @@ CommunicationState::getReport() const {
 
 CommunicationState4::CommunicationState4(const IOServicePtr& io_service,
                                          const HAConfigPtr& config)
-    : CommunicationState(io_service, config), connecting_clients_(),
-      mutex_(new mutex()) {
+    : CommunicationState(io_service, config), connecting_clients_() {
 }
 
 void
@@ -439,8 +452,8 @@ CommunicationState4::analyzeMessageInternal(const boost::shared_ptr<dhcp::Pkt>&
     if (log_unacked) {
         unsigned unacked_left = 0;
         unsigned unacked_total = connecting_clients_.get<1>().count(true);
-        if (config_->getMaxUnackedClients() > unacked_total) {
-            unacked_left = config_->getMaxUnackedClients() - unacked_total;
+        if (config_->getMaxUnackedClients() >= unacked_total) {
+            unacked_left = config_->getMaxUnackedClients() - unacked_total + 1;
         }
         LOG_INFO(ha_logger, HA_COMMUNICATION_INTERRUPTED_CLIENT4_UNACKED)
             .arg(message->getLabel())
@@ -498,8 +511,7 @@ CommunicationState4::clearConnectingClients() {
 
 CommunicationState6::CommunicationState6(const IOServicePtr& io_service,
                                          const HAConfigPtr& config)
-    : CommunicationState(io_service, config), connecting_clients_(),
-      mutex_(new mutex()) {
+    : CommunicationState(io_service, config), connecting_clients_() {
 }
 
 void
@@ -571,8 +583,8 @@ CommunicationState6::analyzeMessageInternal(const boost::shared_ptr<dhcp::Pkt>&
     if (log_unacked) {
         unsigned unacked_left = 0;
         unsigned unacked_total = connecting_clients_.get<1>().count(true);
-        if (config_->getMaxUnackedClients() > unacked_total) {
-            unacked_left = config_->getMaxUnackedClients() - unacked_total;
+        if (config_->getMaxUnackedClients() >= unacked_total) {
+            unacked_left = config_->getMaxUnackedClients() - unacked_total + 1;
         }
         LOG_INFO(ha_logger, HA_COMMUNICATION_INTERRUPTED_CLIENT6_UNACKED)
             .arg(message->getLabel())
