@@ -1,4 +1,4 @@
-// Copyright (C) 2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2020-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -114,7 +114,9 @@ public:
     }
 
     /// @brief Return HA configuration with three servers in JSON format.
-    ConstElementPtr createValidJsonConfiguration() const;
+    ///
+    /// @param backup Flag to set this server as backup server.
+    ConstElementPtr createValidJsonConfiguration(bool backup = false) const;
 
     /// @brief Run parters.
     ///
@@ -127,11 +129,12 @@ public:
 };
 
 ConstElementPtr
-CloseHATest::createValidJsonConfiguration() const {
-    std::string config_text =
+CloseHATest::createValidJsonConfiguration(bool backup) const {
+    std::ostringstream config_text;
+    config_text <<
         "["
         "     {"
-        "         \"this-server-name\": \"server1\","
+        "         \"this-server-name\": \"" << (!backup ? "server1" : "server2") << "\","
         "         \"mode\": \"passive-backup\","
         "         \"wait-backup-ack\": true,"
         "         \"peers\": ["
@@ -154,7 +157,7 @@ CloseHATest::createValidJsonConfiguration() const {
         "     }"
         "]";
 
-    return (Element::fromJSON(config_text));
+    return (Element::fromJSON(config_text.str()));
 }
 
 void
@@ -303,7 +306,17 @@ CloseHATest::runPartners() {
     }
 }
 
-// Test that checks the library can be close in a DHCPv4 server.
+// Test that checks that the library can be loaded and unloaded from a DHCPv4
+// active server.
+// 1. Creates one active and 2 backup servers.
+// 2. Check that the network state is reset and updated to expected state when
+// creating the HAService by calling the dhcp4_srv_configured hook.
+// 3. Send ha-heartbeat to make the server transition 'passive-backup' state.
+// 4. Call buffer4_receive and leases4_committed hooks to make sure that the
+// parked packet is owned strictly by the HA library.
+// 5. Verify that releasing the query will release all resources.
+// 6. Unload the library which should not have any dangling resources.
+// 7. Verify that the network state is reset on unload.
 TEST_F(CloseHATest, close4) {
     // Start partners.
     wthread_.reset(new WatchedThread());
@@ -340,6 +353,11 @@ TEST_F(CloseHATest, close4) {
     leases->push_back(lease);
     Lease4CollectionPtr deleted_leases(new Lease4Collection());
 
+    // Check that the disabled state is reset on dhcp4_srv_configured.
+    ASSERT_TRUE(network_state->isServiceEnabled());
+    network_state->disableService(NetworkState::Origin::HA_COMMAND);
+    ASSERT_FALSE(network_state->isServiceEnabled());
+
     // Start HA service.
     EXPECT_TRUE(HooksManager::calloutsPresent(testHooks.hook_index_dhcp4_srv_configured_));
     {
@@ -350,7 +368,9 @@ TEST_F(CloseHATest, close4) {
                                    *handle);
     }
 
-    // Pretend to be the parter.
+    ASSERT_TRUE(network_state->isServiceEnabled());
+
+    // Pretend to be the partner.
     ConstElementPtr command = createCommand("ha-heartbeat", "dhcp4");
     ConstElementPtr response;
     EXPECT_TRUE(HooksManager::commandHandlersPresent("ha-heartbeat"));
@@ -371,6 +391,8 @@ TEST_F(CloseHATest, close4) {
     ASSERT_EQ(Element::string, state->getType());
     EXPECT_EQ("passive-backup", state->stringValue());
 
+    ASSERT_TRUE(network_state->isServiceEnabled());
+
     // Submit packet.
     EXPECT_TRUE(HooksManager::calloutsPresent(testHooks.hook_index_buffer4_receive_));
     {
@@ -422,11 +444,112 @@ TEST_F(CloseHATest, close4) {
     EXPECT_NO_THROW(HooksManager::prepareUnloadLibraries());
     EXPECT_TRUE(HooksManager::unloadLibraries());
 
+    ASSERT_TRUE(network_state->isServiceEnabled());
+
     // Stop partners.
     wthread_->stop();
 }
 
-// Test that checks the library can be close in a DHCPv6 server.
+// Test that checks that the library can be loaded and unloaded from a DHCPv4
+// backup server.
+// 1. Creates one active and 2 backup servers.
+// 2. Check that the network state is reset and updated to expected state when
+// creating the HAService by calling the dhcp4_srv_configured hook.
+// 3. Send ha-heartbeat to make the server transition 'backup' state.
+// 4. Unload the library which should not have any dangling resources.
+// 5. Verify that the network state is reset on unload.
+TEST_F(CloseHATest, close4Backup) {
+    // Start partners.
+    wthread_.reset(new WatchedThread());
+    wthread_->start([this] () { runPartners(); });
+
+    // Prepare parameters,
+    ElementPtr params = Element::createMap();
+    params->set("high-availability", createValidJsonConfiguration(true));
+
+    // Set family and proc name.
+    CfgMgr::instance().setFamily(AF_INET);
+    Daemon::setProcName("kea-dhcp4");
+
+    // Load the library.
+    HookLibsCollection libraries;
+    libraries.push_back(make_pair(LIBDHCP_HA_SO, params));
+    ASSERT_TRUE(HooksManager::loadLibraries(libraries));
+
+    // Prepare objects.
+    IOServicePtr io_service(new IOService());
+    NetworkStatePtr network_state(new NetworkState(NetworkState::DHCPv4));
+
+    // Check that the state is computed on dhcp4_srv_configured.
+    // It is first reset by the constructor and then adjusted by running the
+    // state model.
+    ASSERT_TRUE(network_state->isServiceEnabled());
+    network_state->disableService(NetworkState::Origin::HA_COMMAND);
+    ASSERT_FALSE(network_state->isServiceEnabled());
+
+    // Start HA service.
+    EXPECT_TRUE(HooksManager::calloutsPresent(testHooks.hook_index_dhcp4_srv_configured_));
+    {
+        CalloutHandlePtr handle = HooksManager::createCalloutHandle();
+        handle->setArgument("io_context", io_service);
+        handle->setArgument("network_state", network_state);
+        HooksManager::callCallouts(testHooks.hook_index_dhcp4_srv_configured_,
+                                   *handle);
+    }
+
+    ASSERT_FALSE(network_state->isServiceEnabled());
+
+    // Transition to backup state.
+    ConstElementPtr command = createCommand("ha-heartbeat", "dhcp4");
+    ConstElementPtr response;
+    EXPECT_TRUE(HooksManager::commandHandlersPresent("ha-heartbeat"));
+    {
+        CalloutHandlePtr handle = HooksManager::createCalloutHandle();
+        handle->setArgument("command", command);
+        handle->setArgument("response", response);
+        HooksManager::callCommandHandlers("ha-heartbeat", *handle);
+        handle->getArgument("response", response);
+    }
+    int code = 0;
+    ConstElementPtr arguments = parseAnswer(code, response);
+    EXPECT_EQ(0, code);
+    ASSERT_TRUE(arguments);
+    ASSERT_EQ(Element::map, arguments->getType());
+    ConstElementPtr state = arguments->get("state");
+    ASSERT_TRUE(state);
+    ASSERT_EQ(Element::string, state->getType());
+    EXPECT_EQ("backup", state->stringValue());
+
+    ASSERT_FALSE(network_state->isServiceEnabled());
+
+    // Done: purge I/Os.
+    io_service->poll();
+    io_service->stop();
+    io_service.reset();
+
+    EXPECT_TRUE(HooksManager::unloadLibraries());
+
+    // Tell the HA to cleanup first.
+    EXPECT_NO_THROW(HooksManager::prepareUnloadLibraries());
+    EXPECT_TRUE(HooksManager::unloadLibraries());
+
+    ASSERT_TRUE(network_state->isServiceEnabled());
+
+    // Stop partners.
+    wthread_->stop();
+}
+
+// Test that checks that the library can be loaded and unloaded from a DHCPv6
+// active server.
+// 1. Creates one active and 2 backup servers.
+// 2. Check that the network state is reset and updated to expected state when
+// creating the HAService by calling the dhcp6_srv_configured hook.
+// 3. Send ha-heartbeat to make the server transition 'passive-backup' state.
+// 4. Call buffer6_receive and leases6_committed hooks to make sure that the
+// parked packet is owned strictly by the HA library.
+// 5. Verify that releasing the query will release all resources.
+// 6. Unload the library which should not have any dangling resources.
+// 7. Verify that the network state is reset on unload.
 TEST_F(CloseHATest, close6) {
     // Start partners.
     wthread_.reset(new WatchedThread());
@@ -463,6 +586,11 @@ TEST_F(CloseHATest, close6) {
     leases->push_back(lease);
     Lease6CollectionPtr deleted_leases(new Lease6Collection());
 
+    // Check that the disabled state is reset on dhcp6_srv_configured.
+    ASSERT_TRUE(network_state->isServiceEnabled());
+    network_state->disableService(NetworkState::Origin::HA_COMMAND);
+    ASSERT_FALSE(network_state->isServiceEnabled());
+
     // Start HA service.
     EXPECT_TRUE(HooksManager::calloutsPresent(testHooks.hook_index_dhcp6_srv_configured_));
     {
@@ -473,7 +601,9 @@ TEST_F(CloseHATest, close6) {
                                    *handle);
     }
 
-    // Pretend to be the parter.
+    ASSERT_TRUE(network_state->isServiceEnabled());
+
+    // Pretend to be the partner.
     ConstElementPtr command = createCommand("ha-heartbeat", "dhcp6");
     ConstElementPtr response;
     EXPECT_TRUE(HooksManager::commandHandlersPresent("ha-heartbeat"));
@@ -494,6 +624,8 @@ TEST_F(CloseHATest, close6) {
     ASSERT_EQ(Element::string, state->getType());
     EXPECT_EQ("passive-backup", state->stringValue());
 
+    ASSERT_TRUE(network_state->isServiceEnabled());
+
     // Submit packet.
     EXPECT_TRUE(HooksManager::calloutsPresent(testHooks.hook_index_buffer6_receive_));
     {
@@ -545,6 +677,97 @@ TEST_F(CloseHATest, close6) {
     EXPECT_NO_THROW(HooksManager::prepareUnloadLibraries());
     EXPECT_TRUE(HooksManager::unloadLibraries());
 
+    ASSERT_TRUE(network_state->isServiceEnabled());
+
+    // Stop partners.
+    wthread_->stop();
+}
+
+// Test that checks that the library can be loaded and unloaded from a DHCPv6
+// backup server.
+// 1. Creates one active and 2 backup servers.
+// 2. Check that the network state is reset and updated to expected state when
+// creating the HAService by calling the dhcp6_srv_configured hook.
+// 3. Send ha-heartbeat to make the server transition 'backup' state.
+// 4. Unload the library which should not have any dangling resources.
+// 5. Verify that the network state is reset on unload.
+TEST_F(CloseHATest, close6Backup) {
+    // Start partners.
+    wthread_.reset(new WatchedThread());
+    wthread_->start([this] () { runPartners(); });
+
+    // Prepare parameters,
+    ElementPtr params = Element::createMap();
+    params->set("high-availability", createValidJsonConfiguration(true));
+
+    // Set family and proc name.
+    CfgMgr::instance().setFamily(AF_INET6);
+    Daemon::setProcName("kea-dhcp6");
+
+    // Load the library.
+    HookLibsCollection libraries;
+    libraries.push_back(make_pair(LIBDHCP_HA_SO, params));
+    ASSERT_TRUE(HooksManager::loadLibraries(libraries));
+
+    // Prepare objects.
+    IOServicePtr io_service(new IOService());
+    NetworkStatePtr network_state(new NetworkState(NetworkState::DHCPv6));
+
+    // Check that the state is computed on dhcp6_srv_configured.
+    // It is first reset by the constructor and then adjusted by running the
+    // state model.
+    ASSERT_TRUE(network_state->isServiceEnabled());
+    network_state->disableService(NetworkState::Origin::HA_COMMAND);
+    ASSERT_FALSE(network_state->isServiceEnabled());
+
+    // Start HA service.
+    EXPECT_TRUE(HooksManager::calloutsPresent(testHooks.hook_index_dhcp6_srv_configured_));
+    {
+        CalloutHandlePtr handle = HooksManager::createCalloutHandle();
+        handle->setArgument("io_context", io_service);
+        handle->setArgument("network_state", network_state);
+        HooksManager::callCallouts(testHooks.hook_index_dhcp6_srv_configured_,
+                                   *handle);
+    }
+
+    ASSERT_FALSE(network_state->isServiceEnabled());
+
+    // Transition to backup state.
+    ConstElementPtr command = createCommand("ha-heartbeat", "dhcp6");
+    ConstElementPtr response;
+    EXPECT_TRUE(HooksManager::commandHandlersPresent("ha-heartbeat"));
+    {
+        CalloutHandlePtr handle = HooksManager::createCalloutHandle();
+        handle->setArgument("command", command);
+        handle->setArgument("response", response);
+        HooksManager::callCommandHandlers("ha-heartbeat", *handle);
+        handle->getArgument("response", response);
+    }
+    int code = 0;
+    ConstElementPtr arguments = parseAnswer(code, response);
+    EXPECT_EQ(0, code);
+    ASSERT_TRUE(arguments);
+    ASSERT_EQ(Element::map, arguments->getType());
+    ConstElementPtr state = arguments->get("state");
+    ASSERT_TRUE(state);
+    ASSERT_EQ(Element::string, state->getType());
+    EXPECT_EQ("backup", state->stringValue());
+
+    ASSERT_FALSE(network_state->isServiceEnabled());
+
+    // Done: purge I/Os.
+    io_service->poll();
+    io_service->stop();
+    io_service.reset();
+
+    EXPECT_TRUE(HooksManager::unloadLibraries());
+
+    // Tell the HA to cleanup first.
+    EXPECT_NO_THROW(HooksManager::prepareUnloadLibraries());
+    EXPECT_TRUE(HooksManager::unloadLibraries());
+
+    ASSERT_TRUE(network_state->isServiceEnabled());
+
     // Stop partners.
     wthread_->stop();
 }
