@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2017 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2020 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -9,7 +9,9 @@
 #include <dhcp_ddns/dhcp_ddns_log.h>
 #include <dhcp_ddns/ncr_udp.h>
 
-#include <boost/bind.hpp>
+#include <functional>
+
+namespace ph = std::placeholders;
 
 namespace isc {
 namespace dhcp_ddns {
@@ -19,7 +21,7 @@ UDPCallback::UDPCallback (RawBufferPtr& buffer, const size_t buf_size,
                           UDPEndpointPtr& data_source,
                           const UDPCompletionHandler& handler)
     : handler_(handler), data_(new Data(buffer, buf_size, data_source)) {
-    if (handler.empty()) {
+    if (!handler) {
         isc_throw(NcrUDPError, "UDPCallback - handler can't be null");
     }
 
@@ -72,10 +74,9 @@ NameChangeUDPListener(const isc::asiolink::IOAddress& ip_address,
     // pointer to our completion handler method, receiveCompletionHandler.
     RawBufferPtr buffer(new uint8_t[RECV_BUF_MAX]);
     UDPEndpointPtr data_source(new asiolink::UDPEndpoint());
-    recv_callback_.reset(new
-                         UDPCallback(buffer, RECV_BUF_MAX, data_source,
-                                     boost::bind(&NameChangeUDPListener::
-                                     receiveCompletionHandler, this, _1, _2)));
+    recv_callback_.reset(new UDPCallback(buffer, RECV_BUF_MAX, data_source,
+        std::bind(&NameChangeUDPListener::receiveCompletionHandler,
+                  this, ph::_1, ph::_2)));
 }
 
 NameChangeUDPListener::~NameChangeUDPListener() {
@@ -102,7 +103,7 @@ NameChangeUDPListener::open(isc::asiolink::IOService& io_service) {
 
         // Bind the low level socket to our endpoint.
         asio_socket_->bind(endpoint.getASIOEndpoint());
-    } catch (boost::system::system_error& ex) {
+    } catch (const boost::system::system_error& ex) {
         asio_socket_.reset();
         isc_throw (NcrUDPError, ex.code().message());
     }
@@ -114,7 +115,7 @@ NameChangeUDPListener::open(isc::asiolink::IOService& io_service) {
 
 void
 NameChangeUDPListener::doReceive() {
-    // Call the socket's asychronous receiving, passing ourself in as callback.
+    // Call the socket's asynchronous receiving, passing ourself in as callback.
     RawBufferPtr recv_buffer = recv_callback_->getBuffer();
     socket_->asyncReceive(recv_buffer.get(), recv_callback_->getBufferSize(),
                           0, recv_callback_->getDataSource().get(),
@@ -132,7 +133,7 @@ NameChangeUDPListener::close() {
         if (asio_socket_->is_open()) {
             try {
                 asio_socket_->close();
-            } catch (boost::system::system_error& ex) {
+            } catch (const boost::system::system_error& ex) {
                 // It is really unlikely that this will occur.
                 // If we do reopen later it will be with a new socket
                 // instance. Repackage exception as one that is conformant
@@ -208,9 +209,8 @@ NameChangeUDPSender(const isc::asiolink::IOAddress& ip_address,
     RawBufferPtr buffer(new uint8_t[SEND_BUF_MAX]);
     UDPEndpointPtr data_source(new asiolink::UDPEndpoint());
     send_callback_.reset(new UDPCallback(buffer, SEND_BUF_MAX, data_source,
-                                         boost::bind(&NameChangeUDPSender::
-                                         sendCompletionHandler, this,
-                                         _1, _2)));
+        std::bind(&NameChangeUDPSender::sendCompletionHandler,
+                  this, ph::_1, ph::_2)));
 }
 
 NameChangeUDPSender::~NameChangeUDPSender() {
@@ -237,7 +237,7 @@ NameChangeUDPSender::open(isc::asiolink::IOService& io_service) {
 
         // Bind the low level socket to our endpoint.
         asio_socket_->bind(endpoint.getASIOEndpoint());
-    } catch (boost::system::system_error& ex) {
+    } catch (const boost::system::system_error& ex) {
         isc_throw (NcrUDPError, ex.code().message());
     }
 
@@ -265,7 +265,7 @@ NameChangeUDPSender::close() {
         if (asio_socket_->is_open()) {
             try {
                 asio_socket_->close();
-            } catch (boost::system::system_error& ex) {
+            } catch (const boost::system::system_error& ex) {
                 // It is really unlikely that this will occur.
                 // If we do reopen later it will be with a new socket
                 // instance. Repackage exception as one that is conformant
@@ -294,7 +294,7 @@ NameChangeUDPSender::doSend(NameChangeRequestPtr& ncr) {
     send_callback_->putData(static_cast<const uint8_t*>(ncr_buffer.getData()),
                             ncr_buffer.getLength());
 
-    // Call the socket's asychronous send, passing our callback
+    // Call the socket's asynchronous send, passing our callback
     socket_->asyncSend(send_callback_->getData(), send_callback_->getPutLen(),
                        send_callback_->getDataSource().get(), *send_callback_);
 
