@@ -1,4 +1,4 @@
-// Copyright (C) 2015-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2015-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -200,7 +200,7 @@ TEST(ClientClassDef, copyAndEquality) {
     def = LibDHCP::getLastResortOptionDef(DHCP4_OPTION_SPACE, 43);
     EXPECT_TRUE(def);
     CfgOptionDefPtr cfg(new CfgOptionDef());
-    ASSERT_NO_THROW(cfg->add(def, DHCP4_OPTION_SPACE));
+    ASSERT_NO_THROW(cfg->add(def));
     cclass2->setCfgOptionDef(cfg);
     EXPECT_FALSE(cclass->equals(*cclass2));
     EXPECT_FALSE(*cclass == *cclass2);
