@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -326,8 +326,8 @@ TEST_F(SrvConfigTest, copy) {
     conf1.addLoggingInfo(info);
 
     // Add option definition.
-    OptionDefinitionPtr def(new OptionDefinition("option-foo", 5, "string"));
-    conf1.getCfgOptionDef()->add(def, "isc");
+    OptionDefinitionPtr def(new OptionDefinition("option-foo", 5, "isc", "string"));
+    conf1.getCfgOptionDef()->add(def);
 
     // Add an option.
     OptionPtr option(new Option(Option::V6, 1000, OptionBuffer(10, 0xFF)));
@@ -390,15 +390,15 @@ TEST_F(SrvConfigTest, equality) {
 
     // Differ by option definitions.
     conf1.getCfgOptionDef()->
-        add(OptionDefinitionPtr(new OptionDefinition("option-foo", 123,
-                                                     "uint16_t")), "isc");
+        add(OptionDefinitionPtr(new OptionDefinition("option-foo", 123, "isc",
+                                                     "uint16_t")));
 
     EXPECT_FALSE(conf1 == conf2);
     EXPECT_TRUE(conf1 != conf2);
 
     conf2.getCfgOptionDef()->
-        add(OptionDefinitionPtr(new OptionDefinition("option-foo", 123,
-                                                     "uint16_t")), "isc");
+        add(OptionDefinitionPtr(new OptionDefinition("option-foo", 123, "isc",
+                                                     "uint16_t")));
     EXPECT_TRUE(conf1 == conf2);
     EXPECT_FALSE(conf1 != conf2);
 
