@@ -1,4 +1,4 @@
-// Copyright (C) 2011-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2011-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -284,8 +284,7 @@ writeHeaderFile(const string& file, const vector<string>& ns_components,
     // after the last write.
 
     hfile <<
-        "// File created from " << message_file.fullName() << " on " <<
-            currentTime() << "\n" <<
+        "// File created from " << message_file.fullName() << "\n" <<
          "\n" <<
          "#ifndef " << sentinel_text << "\n" <<
          "#define "  << sentinel_text << "\n" <<
@@ -389,8 +388,7 @@ writeProgramFile(const string& file, const vector<string>& ns_components,
     // the last write.
 
     ccfile <<
-        "// File created from " << message_file.fullName() << " on " <<
-            currentTime() << "\n" <<
+        "// File created from " << message_file.fullName() << "\n" <<
          "\n" <<
          "#include <cstddef>\n" <<
          "#include <log/message_types.h>\n" <<
