@@ -241,13 +241,13 @@ public:
     /// Initialize MySqlConnection object with parameters needed for connection.
     ///
     /// @param parameters Specify the connection details.
-    /// @param io_service The IOService object, used for all ASIO operations.
+    /// @param io_accessor The IOService accessor function.
     /// @param callback The connection recovery callback.
     MySqlConnection(const ParameterMap& parameters,
-                    const isc::asiolink::IOServicePtr& io_service = isc::asiolink::IOServicePtr(),
+                    IOServiceAccessorPtr io_accessor = IOServiceAccessorPtr(),
                     DbCallback callback = DbCallback())
-        : DatabaseConnection(parameters), io_service_(io_service),
-          callback_(callback) {
+        : DatabaseConnection(parameters, callback),
+          io_service_accessor_(io_accessor), io_service_() {
     }
 
     /// @brief Destructor
@@ -657,8 +657,15 @@ public:
     ///
     /// @note The recover function must be run on the IO Service thread.
     void startRecoverDbConnection() {
-        if (callback_ && io_service_) {
-            io_service_->post(std::bind(callback_, reconnectCtl()));
+        if (callback_) {
+            if (!io_service_ && io_service_accessor_) {
+                io_service_ = (*io_service_accessor_)();
+                io_service_accessor_.reset();
+            }
+
+            if (io_service_) {
+                io_service_->post(std::bind(callback_, reconnectCtl()));
+            }
         }
     }
 
@@ -680,11 +687,17 @@ public:
     /// and will be from MySqlHostDataSource.
     MySqlHolder mysql_;
 
+    /// @brief Accessor function which returns the IOService that can be used to
+    /// recover the connection.
+    ///
+    /// This accessor is used to lazy retrieve the IOService when the connection
+    /// is lost. It is useful to retrieve it at a later time to support hook
+    /// libraries which create managers on load and set IOService later on by
+    /// using the dhcp4_srv_configured and dhcp6_srv_configured hooks.
+    IOServiceAccessorPtr io_service_accessor_;
+
     /// @brief IOService object, used for all ASIO operations.
     isc::asiolink::IOServicePtr io_service_;
-
-    /// @brief The callback used to recover the connection.
-    DbCallback callback_;
 };
 
 } // end of isc::db namespace
