@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -11,6 +11,8 @@
 #include <exceptions/exceptions.h>
 #include <util/thread_pool.h>
 
+#include <signal.h>
+
 using namespace isc;
 using namespace isc::util;
 using namespace std;
@@ -62,6 +64,12 @@ public:
         EXPECT_THROW(thread_pool->reset(), InvalidOperation);
         EXPECT_THROW(thread_pool->wait(), InvalidOperation);
         EXPECT_THROW(thread_pool->wait(0), InvalidOperation);
+        sigset_t nsset;
+        pthread_sigmask(SIG_SETMASK, 0, &nsset);
+        EXPECT_EQ(1, sigismember(&nsset, SIGCHLD));
+        EXPECT_EQ(1, sigismember(&nsset, SIGINT));
+        EXPECT_EQ(1, sigismember(&nsset, SIGHUP));
+        EXPECT_EQ(1, sigismember(&nsset, SIGTERM));
         EXPECT_NO_THROW(runAndWait());
     }
 
